@@ -1,5 +1,5 @@
 from ._abstract import AbstractScraper
-from ._utils import get_yields, normalize_string
+from ._utils import normalize_string
 
 
 class CookingLight(AbstractScraper):
@@ -7,9 +7,6 @@ class CookingLight(AbstractScraper):
     def host(cls):
         return "cookinglight.com"
 
-    def yields(self):
-        return get_yields(self.schema.yields())
-
     def ingredients(self):
         ingredients = self.soup.find("div", {"class": "ingredients"}).ul.findAll("li")
         return "\n".join(
